@@ -20,34 +20,32 @@
  *
  * SPDX-License-Identifier: curl
  *
- ***************************************************************************/
+ * To compile:
+ *   gcc crawler.c $(pkg-config --cflags --libs libxml-2.0 libcurl)
+ *
+ */
 /* <DESC>
  * Web crawler based on curl and libxml2 to stress-test curl with
  * hundreds of concurrent connections to various servers.
  * </DESC>
  */
-/*
- * To compile:
- *   gcc crawler.c $(pkg-config --cflags --libs libxml-2.0 libcurl)
- */
+
 #include <libxml/HTMLparser.h>
 #include <libxml/xpath.h>
 #include <libxml/uri.h>
-
+#include <curl/curl.h>
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 #include <signal.h>
 
-#include <curl/curl.h>
-
 /* Parameters */
 static int max_con = 200;
 static int max_total = 20000;
 static int max_requests = 500;
 static size_t max_link_per_page = 5;
 static int follow_relative_links = 0;
-static const char *start_page = "https://www.reuters.com/";
+static const char *start_page = "https://www.reuters.com";
 
 static int pending_interrupt = 0;
 static void sighandler(int dummy)
@@ -65,7 +63,7 @@ struct memory {
 static size_t write_cb(void *contents, size_t sz, size_t nmemb, void *ctx)
 {
   size_t realsize = sz * nmemb;
-  struct memory *mem = (struct memory *)ctx;
+  struct memory *mem = (struct memory*) ctx;
   char *ptr = realloc(mem->buf, mem->size + realsize);
   if(!ptr) {
     /* out of memory */
@@ -109,7 +107,7 @@ static CURL *make_handle(const char *url)
   curl_easy_setopt(curl, CURLOPT_CONNECTTIMEOUT_MS, 2000L);
   /* skip files larger than a gigabyte */
   curl_easy_setopt(curl, CURLOPT_MAXFILESIZE_LARGE,
-                   (curl_off_t)1024 * 1024 * 1024);
+                   (curl_off_t)1024*1024*1024);
   curl_easy_setopt(curl, CURLOPT_COOKIEFILE, "");
   curl_easy_setopt(curl, CURLOPT_FILETIME, 1L);
   curl_easy_setopt(curl, CURLOPT_USERAGENT, "mini crawler");
@@ -121,10 +119,11 @@ static CURL *make_handle(const char *url)
 }
 
 /* HREF finder implemented in libxml2 but could be any HTML parser */
-static size_t follow_links(CURLM *multi, struct memory *mem, const char *url)
+static size_t follow_links(CURLM *multi, struct memory *mem,
+                           const char *url)
 {
-  int opts = HTML_PARSE_NOBLANKS | HTML_PARSE_NOERROR | HTML_PARSE_NOWARNING |
-             HTML_PARSE_NONET;
+  int opts = HTML_PARSE_NOBLANKS | HTML_PARSE_NOERROR | \
+             HTML_PARSE_NOWARNING | HTML_PARSE_NONET;
   htmlDocPtr doc = htmlReadMemory(mem->buf, (int)mem->size, url, NULL, opts);
   size_t count;
   int i;
@@ -134,7 +133,7 @@ static size_t follow_links(CURLM *multi, struct memory *mem, const char *url)
   xmlXPathObjectPtr result;
   if(!doc)
     return 0;
-  xpath = (xmlChar *)"//a/@href";
+  xpath = (xmlChar*) "//a/@href";
   context = xmlXPathNewContext(doc);
   result = xmlXPathEvalExpression(xpath, context);
   xmlXPathFreeContext(context);
@@ -154,10 +153,10 @@ static size_t follow_links(CURLM *multi, struct memory *mem, const char *url)
     char *link;
     if(follow_relative_links) {
       xmlChar *orig = href;
-      href = xmlBuildURI(href, (xmlChar *)url);
+      href = xmlBuildURI(href, (xmlChar *) url);
       xmlFree(orig);
     }
-    link = (char *)href;
+    link = (char *) href;
     if(!link || strlen(link) < 20)
       continue;
     if(!strncmp(link, "http://", 7) || !strncmp(link, "https://", 8)) {
@@ -171,7 +170,7 @@ static size_t follow_links(CURLM *multi, struct memory *mem, const char *url)
   return count;
 }
 
-static int is_html(const char *ctype)
+static int is_html(char *ctype)
 {
   return ctype != NULL && strlen(ctype) > 10 && strstr(ctype, "text/html");
 }
@@ -183,11 +182,11 @@ int main(void)
   int pending;
   int complete;
   int still_running;
-  CURLcode result;
+  CURLcode res;
 
-  result = curl_global_init(CURL_GLOBAL_ALL);
-  if(result)
-    return (int)result;
+  res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res)
+    return (int)res;
 
   signal(SIGINT, sighandler);
   LIBXML_TEST_VERSION
@@ -239,7 +238,7 @@ int main(void)
               }
             }
             else {
-              printf("[%d] HTTP %d: %s\n", complete, (int)res_status, url);
+              printf("[%d] HTTP %d: %s\n", complete, (int) res_status, url);
             }
           }
           else {
