@@ -32,13 +32,6 @@
  *
  */
 
-#ifdef _WIN32
-#ifndef _CRT_SECURE_NO_WARNINGS
-#define _CRT_SECURE_NO_WARNINGS
-#endif
-#include <windows.h>
-#endif
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,6 +40,10 @@
 #include <curl/curl.h>
 
 #ifdef _WIN32
+#ifndef _CRT_SECURE_NO_WARNINGS
+#define _CRT_SECURE_NO_WARNINGS
+#endif
+#include <windows.h>
 #define strcasecmp _stricmp
 #define strncasecmp _strnicmp
 #define unlink _unlink
@@ -131,7 +128,7 @@ static int mem_add(struct mem *mem, const char *str)
 }
 
 #if defined(__GNUC__) || defined(__clang__)
-__attribute__ ((format (printf, 2, 3)))
+__attribute__((format(printf, 2, 3)))
 #endif
 static int mem_addf(struct mem *mem, const char *format, ...)
 {
@@ -141,8 +138,8 @@ static int mem_addf(struct mem *mem, const char *format, ...)
   /* we need about 100 chars or less to write 95% of lines */
   x = 128;
 
-  /* first try: there's probably enough memory to write everything.
-     second try: there's definitely enough memory to write everything. */
+  /* first try: there is probably enough memory to write everything.
+     second try: there is definitely enough memory to write everything. */
   for(i = 0; i < 2; ++i) {
     if(x < 0 || mem_need(mem, (size_t)x + 1) < 0)
       break;
@@ -173,14 +170,14 @@ static int mem_addf(struct mem *mem, const char *format, ...)
   return -1;
 }
 
-static int mydebug(CURL *handle, curl_infotype type,
+static int mydebug(CURL *curl, curl_infotype type,
                    char *data, size_t size, void *userdata)
 {
   struct transfer *t = (struct transfer *)userdata;
   static const char s_infotype[CURLINFO_END][3] = {
     "* ", "< ", "> ", "{ ", "} ", "{ ", "} " };
 
-  (void)handle;
+  (void)curl;
 
   switch(type) {
   case CURLINFO_TEXT:
@@ -199,7 +196,7 @@ static int mydebug(CURL *handle, curl_infotype type,
   return 0;
 }
 
-static size_t mywrite(char *ptr, size_t size, size_t nmemb, void *userdata)
+static size_t write_cb(char *ptr, size_t size, size_t nmemb, void *userdata)
 {
   struct transfer *t = (struct transfer *)userdata;
 
@@ -208,6 +205,7 @@ static size_t mywrite(char *ptr, size_t size, size_t nmemb, void *userdata)
 
 int main(void)
 {
+  CURLcode res;
   unsigned i;
   int total_failed = 0;
   char errbuf[CURL_ERROR_SIZE] = { 0, };
@@ -223,9 +221,10 @@ int main(void)
   transfer[1].bodyfile = "400.txt";
   transfer[1].logfile = "400_transfer_log.txt";
 
-  if(curl_global_init(CURL_GLOBAL_DEFAULT)) {
+  res = curl_global_init(CURL_GLOBAL_ALL);
+  if(res) {
     fprintf(stderr, "curl_global_init failed\n");
-    return 1;
+    return (int)res;
   }
 
   /* You could enable global tracing for extra verbosity when verbosity is
@@ -257,7 +256,7 @@ int main(void)
     curl_easy_setopt(t->curl, CURLOPT_DEBUGDATA, t);
 
     /* Enable writing the body to a file */
-    curl_easy_setopt(t->curl, CURLOPT_WRITEFUNCTION, mywrite);
+    curl_easy_setopt(t->curl, CURLOPT_WRITEFUNCTION, write_cb);
     curl_easy_setopt(t->curl, CURLOPT_WRITEDATA, t);
 
     /* Enable immediate error on HTTP status codes >= 400 in most cases,
@@ -331,5 +330,7 @@ int main(void)
     printf("\n");
   }
 
+  curl_global_cleanup();
+
   return total_failed ? 1 : 0;
 }
